@@ -7,6 +7,7 @@ from aiosmb import logger
 from aiosmb.commons.interfaces.share import SMBShare
 from aiosmb.commons.interfaces.session import SMBUserSession
 from aiosmb.commons.interfaces.file import SMBFile
+from aiosmb.commons.interfaces.directory import SMBDirectory
 from aiosmb.dcerpc.v5.interfaces.srvsmgr import SMBSRVS
 from aiosmb.dcerpc.v5.interfaces.samrmgr import SMBSAMR
 from aiosmb.dcerpc.v5.interfaces.lsatmgr import LSAD
@@ -261,6 +262,9 @@ class SMBMachine:
 	async def list_shares(self):
 		try:
 			async for name, share_type, remark, err in self.srvs.list_shares():
+				if err is not None:
+					yield None, err
+					return
 				share = SMBShare(
 					name = name, 
 					stype = share_type, 
@@ -395,6 +399,9 @@ class SMBMachine:
 
 	async def del_file(self, file_path):
 		return await SMBFile.delete(self.connection, file_path)
+	
+	async def del_directory_path(self, dir_path):
+		return await SMBDirectory.delete_unc(self.connection, dir_path)
 
 	async def create_subdirectory(self, directory_name, parent_directory_obj):
 		await parent_directory_obj.create_subdir(directory_name, self.connection)
@@ -433,6 +440,8 @@ class SMBMachine:
 
 	async def dcsync(self, target_domain = None, target_users = []):
 		try:
+			if isinstance(target_users, str):
+				target_users = [target_users]
 			if self.samr is None:
 				await self.connect_rpc('SAMR')
 
@@ -493,7 +502,10 @@ class SMBMachine:
 
 	@req_rrp
 	async def save_registry_hive(self, hive_name, remote_path):
-		res, err = await self.rrp.SaveKey(hive_name, remote_path)
+		key_handle, err = await self.rrp.OpenRegPath(hive_name)
+		if err is not None:
+			return None, err
+		res, err = await self.rrp.SaveKey(key_handle, remote_path)
 		return res, err
 
 	@req_servicemanager
@@ -507,6 +519,22 @@ class SMBMachine:
 		res, err = await self.servicemanager.create_service(service_name, display_name, command)
 		return res, err
 
+	@req_servicemanager
+	async def start_service(self, service_name):
+		"""
+		Creates a service and starts it.
+		Does not create files! there is a separate command for that!
+		"""
+		return await self.servicemanager.start_service(service_name)
+	
+	@req_servicemanager
+	async def stop_service(self, service_name):
+		"""
+		Creates a service and starts it.
+		Does not create files! there is a separate command for that!
+		"""
+		return await self.servicemanager.stop_service(service_name)
+
 
 	@req_servicemanager
 	async def deploy_service(self, path_to_executable, remote_path = None, service_name = None):
@@ -569,6 +597,7 @@ class SMBMachine:
 
 		))
 		print('got resp! %s' % resp)
+		return True, None
 
 	async def list_interfaces(self):
 		try:
@@ -601,9 +630,7 @@ class SMBMachine:
 	async def check_service_status(self, service_name):
 		return await self.servicemanager.check_service_status(service_name)
 
-	async def stop_service(self):
-		pass
-	
+
 	async def list_mountpoints(self):
 		pass
 	
