@@ -28,7 +28,7 @@ from six import PY2
 from aiosmb import logger as LOG
 from aiosmb.dcerpc.v5.ndr import NDRCALL, NDRSTRUCT, NDRPOINTER, NDRUniConformantArray, NDRUNION, NDR, NDRENUM
 from aiosmb.dcerpc.v5.dtypes import PUUID, DWORD, NULL, GUID, LPWSTR, BOOL, ULONG, UUID, LONGLONG, ULARGE_INTEGER, LARGE_INTEGER
-from aiosmb.dcerpc.v5 import hresult_errors
+from aiosmb.dcerpc.v5 import hresult_errors, system_errors
 from aiosmb.dcerpc.v5.structure import Structure
 from aiosmb.dcerpc.v5.uuid import uuidtup_to_bin, string_to_bin
 from aiosmb.dcerpc.v5.enum import Enum
@@ -38,15 +38,6 @@ from asn1crypto.core import ObjectIdentifier
 from aiosmb.crypto.symmetric import RC4, DES
 from aiosmb.crypto.BASE import cipherMODE
 
-##### THIS CODE NEEDS TO BE CLEANED UP!!!!
-#from pyasn1.type import univ
-#from impacket.crypto import transformKey
-
-#try:
-#	from Cryptodome.Cipher import ARC4, DES
-#except Exception:
-#	LOG.critical("Warning: You don't have any crypto installed. You need pycryptodomex")
-#	LOG.critical("See https://pypi.org/project/pycryptodomex/")
 
 MSRPC_UUID_DRSUAPI = uuidtup_to_bin(('E3514235-4B06-11D1-AB04-00C04FC2DCD2','4.0'))
 
@@ -55,6 +46,15 @@ class DCERPCSessionError(DCERPCException):
 		DCERPCException.__init__(self, error_string, error_code, packet)
 
 	def __str__( self ):
+		key = self.error_code
+		if key in hresult_errors.ERROR_MESSAGES:
+			error_msg_short = hresult_errors.ERROR_MESSAGES[key][0]
+			error_msg_verbose = hresult_errors.ERROR_MESSAGES[key][1]
+			return 'DRSR SessionError: code: 0x%x - %s - %s' % (self.error_code, error_msg_short, error_msg_verbose)
+		elif key & 0xffff in system_errors.ERROR_MESSAGES:
+			error_msg_short = system_errors.ERROR_MESSAGES[key & 0xffff][0]
+			error_msg_verbose = system_errors.ERROR_MESSAGES[key & 0xffff][1]
+			return 'DRSR SessionError: code: 0x%x - %s - %s' % (self.error_code, error_msg_short, error_msg_verbose)
 		return 'DRSR SessionError: unknown error code: 0x%x' % self.error_code
 
 ################################################################################
