@@ -37,6 +37,7 @@ from aiosmb.dcerpc.v5.dtypes import DWORD, UUID, ULONG, LPULONG, BOOLEAN, SECURI
     RPC_UNICODE_STRING, FILETIME, NULL, MAXIMUM_ALLOWED, OWNER_SECURITY_INFORMATION, PWCHAR, PRPC_UNICODE_STRING
 
 from aiosmb.commons.utils.decorators import red, rr
+from aiosmb.dcerpc.v5 import system_errors
 
 MSRPC_UUID_LSAD  = uuidtup_to_bin(('12345778-1234-ABCD-EF00-0123456789AB','0.0'))
 
@@ -44,6 +45,15 @@ class DCERPCSessionError(DCERPCException):
     def __init__(self, error_string=None, error_code=None, packet=None):
         DCERPCException.__init__(self, error_string, error_code, packet)
 
+    def __str__( self ):
+        key = self.error_code
+        if key in system_errors.ERROR_MESSAGES:
+            error_msg_short = system_errors.ERROR_MESSAGES[key][0]
+            error_msg_verbose = system_errors.ERROR_MESSAGES[key][1] 
+            return 'LSAD SessionError: code: 0x%x - %s - %s' % (self.error_code, error_msg_short, error_msg_verbose)
+        else:
+            return 'LSAD SessionError: unknown error code: 0x%x' % self.error_code
+
 
 ################################################################################
 # CONSTANTS
@@ -1601,8 +1611,10 @@ async def hLsarRetrievePrivateData(dce, policyHandle, keyName):
     request = LsarRetrievePrivateData()
     request['PolicyHandle'] = policyHandle
     request['KeyName'] = keyName
-    retVal = await dce.request(request)
-    return b''.join(retVal['EncryptedData']['Buffer'])
+    retVal, err = await dce.request(request)
+    if err is not None:
+        return None, err
+    return b''.join(retVal['EncryptedData']['Buffer']), None
 
 async def hLsarStorePrivateData(dce, policyHandle, keyName, encryptedData):
     request = LsarStorePrivateData()
